@@ -104,8 +104,8 @@ class BasicTA3:
 
                     score_data = {'score': avg_score, 'normalized_score': normalized_score,
                                   'metric': target_metric.name.lower()}
-        if score_data is None:
-            raise RuntimeError('Got an errored status during scoring')
+            elif result.progress.state == pb_core.ERRORED:
+                raise RuntimeError(result.progress.status)
 
         return score_data
 
@@ -132,9 +132,8 @@ class BasicTA3:
                 fitted_solution_id = result.fitted_solution_id
                 for exposed_output in result.exposed_outputs:
                     pipeline_step_outputs[exposed_output] = result.exposed_outputs[exposed_output].csv_uri
-
-        if fitted_solution_id is None:
-            raise RuntimeError('Got an errored status during training')
+            elif result.progress.state == pb_core.ERRORED:
+                raise RuntimeError(result.progress.status)
 
         return fitted_solution_id, pipeline_step_outputs
 
@@ -159,9 +158,8 @@ class BasicTA3:
             if result.progress.state == pb_core.COMPLETED:
                 for exposed_output in result.exposed_outputs:
                     pipeline_step_outputs[exposed_output] = result.exposed_outputs[exposed_output].csv_uri
-
-        if len(pipeline_step_outputs) == 0:
-            raise RuntimeError('Got an errored status during testing')
+            elif result.progress.state == pb_core.ERRORED:
+                raise RuntimeError(result.progress.status)
 
         return pipeline_step_outputs
 
